==> heptapod-rails-0.21.3.tar.gz: heptapod-rails-0.21.3/qa/qa/page/component/invite_members_modal.rb <==
# frozen_string_literal: true

module QA
  module Page
    module Component
      module InviteMembersModal
        extend QA::Page::PageConcern

        def self.included(base)
          super

          base.view 'app/assets/javascripts/invite_members/components/invite_members_modal.vue' do
            element :invite_button
            element :access_level_dropdown
            element :invite_members_modal_content
          end

          base.view 'app/assets/javascripts/invite_members/components/group_select.vue' do
            element :group_select_dropdown_search_field
          end

          base.view 'app/assets/javascripts/invite_members/components/invite_group_trigger.vue' do
            element :invite_a_group_button
          end

          base.view 'app/assets/javascripts/invite_members/components/invite_members_trigger.vue' do
            element :invite_members_button
          end
        end

        def open_invite_members_modal
          click_element :invite_members_button
        end

        def open_invite_group_modal
          click_element :invite_a_group_button
        end

        def add_member(username, access_level = Resource::Members::AccessLevel::DEVELOPER)
          open_invite_members_modal

          within_element(:invite_members_modal_content) do
            fill_element :access_level_dropdown, with: access_level

            fill_in 'Search for members to invite', with: username

            Support::WaitForRequests.wait_for_requests

            click_button username

            click_element :invite_button
          end

          Support::WaitForRequests.wait_for_requests

          page.refresh
        end

        def invite_group(group_name, group_access = Resource::Members::AccessLevel::GUEST)
          open_invite_group_modal

          fill_element :access_level_dropdown, with: group_access

          click_button 'Select a group'
          fill_element :group_select_dropdown_search_field, group_name

          Support::WaitForRequests.wait_for_requests

          click_button group_name

          click_element :invite_button

          Support::WaitForRequests.wait_for_requests

          page.refresh
        end
      end
    end
  end
end

==> heptapod-rails-0.24.0rc1.tar.gz: heptapod-rails-0.24.0rc1/qa/qa/page/component/invite_members_modal.rb <==
# frozen_string_literal: true

module QA
  module Page
    module Component
      module InviteMembersModal
        extend QA::Page::PageConcern

        def self.included(base)
          super

          base.view 'app/assets/javascripts/invite_members/components/invite_members_modal.vue' do
            element :invite_button
            element :access_level_dropdown
            element :invite_members_modal_content
          end

          base.view 'app/assets/javascripts/invite_members/components/group_select.vue' do
            element :group_select_dropdown_search_field
          end

          base.view 'app/assets/javascripts/invite_members/components/invite_group_trigger.vue' do
            element :invite_a_group_button
          end

          base.view 'app/assets/javascripts/invite_members/components/invite_members_trigger.vue' do
            element :invite_members_button
          end
        end

        def open_invite_members_modal
          click_element :invite_members_button
        end

        def open_invite_group_modal
          click_element :invite_a_group_button
        end

        def add_member(username, access_level = Resource::Members::AccessLevel::DEVELOPER)
          open_invite_members_modal

          within_element(:invite_members_modal_content) do
            fill_element :access_level_dropdown, with: access_level

            fill_in 'Select members or type email addresses', with: username

            Support::WaitForRequests.wait_for_requests

            click_button username

            click_element :invite_button
          end

          Support::WaitForRequests.wait_for_requests

          page.refresh
        end

        def invite_group(group_name, group_access = Resource::Members::AccessLevel::GUEST)
          open_invite_group_modal

          fill_element :access_level_dropdown, with: group_access

          click_button 'Select a group'
          fill_element :group_select_dropdown_search_field, group_name

          Support::WaitForRequests.wait_for_requests

          click_button group_name

          click_element :invite_button

          Support::WaitForRequests.wait_for_requests

          page.refresh
        end
      end
    end
  end
end
